@@ -18,6 +18,7 @@
 #include "lldpd.h"
 #include "trace.h"
 
+#include <sys/param.h>
 #include <sys/utsname.h>
 
 static ssize_t
@@ -74,23 +75,24 @@ client_handle_set_configuration(struct lldpd *cfg, enum hmsg_type *type, void *i
 	if (CHANGED(c_tx_interval) && config->c_tx_interval != 0) {
 		if (config->c_tx_interval < 0) {
 			log_debug("rpc", "client asked for immediate retransmission");
-		} else {
+		} else if (config->c_tx_interval <= 3600 * 1000) {
 			log_debug("rpc", "client change transmit interval to %d ms",
 			    config->c_tx_interval);
 			cfg->g_config.c_tx_interval = config->c_tx_interval;
 			cfg->g_config.c_ttl =
 			    cfg->g_config.c_tx_interval * cfg->g_config.c_tx_hold;
-			cfg->g_config.c_ttl = (cfg->g_config.c_ttl + 999) / 1000;
+			cfg->g_config.c_ttl =
+			    MIN((cfg->g_config.c_ttl + 999) / 1000, 65535);
 		}
 		levent_send_now(cfg);
 	}
-	if (CHANGED(c_tx_hold) && config->c_tx_hold > 0) {
+	if (CHANGED(c_tx_hold) && config->c_tx_hold > 0 && config->c_tx_hold <= 100) {
 		log_debug("rpc", "client change transmit hold to %d",
 		    config->c_tx_hold);
 		cfg->g_config.c_tx_hold = config->c_tx_hold;
 		cfg->g_config.c_ttl =
 		    cfg->g_config.c_tx_interval * cfg->g_config.c_tx_hold;
-		cfg->g_config.c_ttl = (cfg->g_config.c_ttl + 999) / 1000;
+		cfg->g_config.c_ttl = MIN((cfg->g_config.c_ttl + 999) / 1000, 65535);
 	}
 	if (CHANGED(c_max_neighbors) && config->c_max_neighbors > 0) {
 		log_debug("rpc", "client change maximum neighbors to %d",
