@@ -24,14 +24,14 @@
 #include <time.h>
 #include <fcntl.h>
 #if defined(__clang__)
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdocumentation"
+#  pragma clang diagnostic push
+#  pragma clang diagnostic ignored "-Wdocumentation"
 #endif
 #include <event2/event.h>
 #include <event2/bufferevent.h>
 #include <event2/buffer.h>
 #if defined(__clang__)
-#pragma clang diagnostic pop
+#  pragma clang diagnostic pop
 #endif
 
 #define EVENT_BUFFER 1024
@@ -40,10 +40,18 @@ static void
 levent_log_cb(int severity, const char *msg)
 {
 	switch (severity) {
-	case _EVENT_LOG_DEBUG: log_debug("libevent", "%s", msg); break;
-	case _EVENT_LOG_MSG:   log_info ("libevent", "%s", msg);  break;
-	case _EVENT_LOG_WARN:  log_warnx("libevent", "%s", msg);  break;
-	case _EVENT_LOG_ERR:   log_warnx("libevent", "%s", msg); break;
+	case _EVENT_LOG_DEBUG:
+		log_debug("libevent", "%s", msg);
+		break;
+	case _EVENT_LOG_MSG:
+		log_info("libevent", "%s", msg);
+		break;
+	case _EVENT_LOG_WARN:
+		log_warnx("libevent", "%s", msg);
+		break;
+	case _EVENT_LOG_ERR:
+		log_warnx("libevent", "%s", msg);
+		break;
 	}
 }
 
@@ -53,29 +61,29 @@ struct lldpd_events {
 };
 TAILQ_HEAD(ev_l, lldpd_events);
 
-#define levent_snmp_fds(cfg)   ((struct ev_l*)(cfg)->g_snmp_fds)
-#define levent_hardware_fds(hardware) ((struct ev_l*)(hardware)->h_recv)
+#define levent_snmp_fds(cfg) ((struct ev_l *)(cfg)->g_snmp_fds)
+#define levent_hardware_fds(hardware) ((struct ev_l *)(hardware)->h_recv)
 
 #ifdef USE_SNMP
-#include <net-snmp/net-snmp-config.h>
-#include <net-snmp/net-snmp-includes.h>
-#include <net-snmp/agent/net-snmp-agent-includes.h>
-#include <net-snmp/agent/snmp_vars.h>
+#  include <net-snmp/net-snmp-config.h>
+#  include <net-snmp/net-snmp-includes.h>
+#  include <net-snmp/agent/net-snmp-agent-includes.h>
+#  include <net-snmp/agent/snmp_vars.h>
 
 /* Compatibility with older versions of NetSNMP */
-#ifndef HAVE_SNMP_SELECT_INFO2
-# define netsnmp_large_fd_set fd_set
-# define snmp_read2 snmp_read
-# define snmp_select_info2 snmp_select_info
-# define netsnmp_large_fd_set_init(...)
-# define netsnmp_large_fd_set_cleanup(...)
-# define NETSNMP_LARGE_FD_SET FD_SET
-# define NETSNMP_LARGE_FD_CLR FD_CLR
-# define NETSNMP_LARGE_FD_ZERO FD_ZERO
-# define NETSNMP_LARGE_FD_ISSET FD_ISSET
-#else
-# include <net-snmp/library/large_fd_set.h>
-#endif
+#  ifndef HAVE_SNMP_SELECT_INFO2
+#    define netsnmp_large_fd_set fd_set
+#    define snmp_read2 snmp_read
+#    define snmp_select_info2 snmp_select_info
+#    define netsnmp_large_fd_set_init(...)
+#    define netsnmp_large_fd_set_cleanup(...)
+#    define NETSNMP_LARGE_FD_SET FD_SET
+#    define NETSNMP_LARGE_FD_CLR FD_CLR
+#    define NETSNMP_LARGE_FD_ZERO FD_ZERO
+#    define NETSNMP_LARGE_FD_ISSET FD_ISSET
+#  else
+#    include <net-snmp/library/large_fd_set.h>
+#  endif
 
 static void levent_snmp_update(struct lldpd *);
 
@@ -107,7 +115,8 @@ static void
 levent_snmp_timeout(evutil_socket_t fd, short what, void *arg)
 {
 	struct lldpd *cfg = arg;
-	(void)what; (void)fd;
+	(void)what;
+	(void)fd;
 	snmp_timeout();
 	run_alarms();
 	levent_snmp_update(cfg);
@@ -132,10 +141,8 @@ levent_snmp_add_fd(struct lldpd *cfg, int fd)
 		return;
 	}
 	levent_make_socket_nonblocking(fd);
-	if ((snmpfd->ev = event_new(base, fd,
-				    EV_READ | EV_PERSIST,
-				    levent_snmp_read,
-				    cfg)) == NULL) {
+	if ((snmpfd->ev = event_new(base, fd, EV_READ | EV_PERSIST, levent_snmp_read,
+		 cfg)) == NULL) {
 		log_warnx("event", "unable to allocate a new SNMP event for FD %d", fd);
 		free(snmpfd);
 		return;
@@ -180,14 +187,12 @@ levent_snmp_update(struct lldpd *cfg)
 
 	netsnmp_large_fd_set fdset;
 	netsnmp_large_fd_set_init(&fdset, FD_SETSIZE);
-        NETSNMP_LARGE_FD_ZERO(&fdset);
+	NETSNMP_LARGE_FD_ZERO(&fdset);
 	snmp_select_info2(&maxfd, &fdset, &timeout, &block);
 
 	/* We need to untrack any event whose FD is not in `fdset`
 	   anymore */
-	for (snmpfd = TAILQ_FIRST(levent_snmp_fds(cfg));
-	     snmpfd;
-	     snmpfd = snmpfd_next) {
+	for (snmpfd = TAILQ_FIRST(levent_snmp_fds(cfg)); snmpfd; snmpfd = snmpfd_next) {
 		snmpfd_next = TAILQ_NEXT(snmpfd, next);
 		if (event_get_fd(snmpfd->ev) >= maxfd ||
 		    (!NETSNMP_LARGE_FD_ISSET(event_get_fd(snmpfd->ev), &fdset))) {
@@ -210,13 +215,14 @@ levent_snmp_update(struct lldpd *cfg)
 	}
 	current += added;
 	if (howmany != current) {
-		log_debug("event", "added %d events, removed %d events, total of %d events",
-			   added, removed, current);
+		log_debug("event",
+		    "added %d events, removed %d events, total of %d events", added,
+		    removed, current);
 		howmany = current;
 	}
 
 	/* If needed, handle timeout */
-	if (evtimer_add(cfg->g_snmp_timeout, block?NULL:&timeout) == -1)
+	if (evtimer_add(cfg->g_snmp_timeout, block ? NULL : &timeout) == -1)
 		log_warnx("event", "unable to schedule timeout function for SNMP");
 
 	netsnmp_large_fd_set_cleanup(&fdset);
@@ -227,7 +233,7 @@ struct lldpd_one_client {
 	TAILQ_ENTRY(lldpd_one_client) next;
 	struct lldpd *cfg;
 	struct bufferevent *bev;
-	int    subscribed;	/* Is this client subscribed to changes? */
+	int subscribed; /* Is this client subscribed to changes? */
 };
 TAILQ_HEAD(, lldpd_one_client) lldpd_clients;
 
@@ -245,9 +251,7 @@ static void
 levent_ctl_close_clients()
 {
 	struct lldpd_one_client *client, *client_next;
-	for (client = TAILQ_FIRST(&lldpd_clients);
-	     client;
-	     client = client_next) {
+	for (client = TAILQ_FIRST(&lldpd_clients); client; client = client_next) {
 		client_next = TAILQ_NEXT(client, next);
 		levent_ctl_free_client(client);
 	}
@@ -273,19 +277,15 @@ void
 levent_ctl_notify(char *ifname, int state, struct lldpd_port *neighbor)
 {
 	struct lldpd_one_client *client, *client_next;
-	struct lldpd_neighbor_change neigh = {
-		.ifname = ifname,
-		.state  = state,
-		.neighbor = neighbor
-	};
+	struct lldpd_neighbor_change neigh = { .ifname = ifname,
+		.state = state,
+		.neighbor = neighbor };
 	void *output = NULL;
 	ssize_t output_len = 0;
 
 	/* Don't use TAILQ_FOREACH, the client may be deleted in case of errors. */
 	log_debug("control", "notify clients of neighbor changes");
-	for (client = TAILQ_FIRST(&lldpd_clients);
-	     client;
-	     client = client_next) {
+	for (client = TAILQ_FIRST(&lldpd_clients); client; client = client_next) {
 		client_next = TAILQ_NEXT(client, next);
 		if (!client->subscribed) continue;
 
@@ -295,14 +295,14 @@ levent_ctl_notify(char *ifname, int state, struct lldpd_port *neighbor)
 			TAILQ_ENTRY(lldpd_port) backup_p_entries;
 			memcpy(&backup_p_entries, &neighbor->p_entries,
 			    sizeof(backup_p_entries));
-			memset(&neighbor->p_entries, 0,
-			    sizeof(backup_p_entries));
+			memset(&neighbor->p_entries, 0, sizeof(backup_p_entries));
 			output_len = lldpd_neighbor_change_serialize(&neigh, &output);
 			memcpy(&neighbor->p_entries, &backup_p_entries,
 			    sizeof(backup_p_entries));
 
 			if (output_len <= 0) {
-				log_warnx("event", "unable to serialize changed neighbor");
+				log_warnx("event",
+				    "unable to serialize changed neighbor");
 				return;
 			}
 		}
@@ -325,15 +325,14 @@ levent_ctl_recv(struct bufferevent *bev, void *ptr)
 {
 	struct lldpd_one_client *client = ptr;
 	struct evbuffer *buffer = bufferevent_get_input(bev);
-	size_t buffer_len       = evbuffer_get_length(buffer);
+	size_t buffer_len = evbuffer_get_length(buffer);
 	struct hmsg_header hdr;
 	void *data = NULL;
 
 	log_debug("control", "receive data on Unix socket");
-	if (buffer_len < sizeof(struct hmsg_header))
-		return;		/* Not enough data yet */
-	if (evbuffer_copyout(buffer, &hdr,
-		sizeof(struct hmsg_header)) != sizeof(struct hmsg_header)) {
+	if (buffer_len < sizeof(struct hmsg_header)) return; /* Not enough data yet */
+	if (evbuffer_copyout(buffer, &hdr, sizeof(struct hmsg_header)) !=
+	    sizeof(struct hmsg_header)) {
 		log_warnx("event", "not able to read header");
 		return;
 	}
@@ -343,7 +342,7 @@ levent_ctl_recv(struct bufferevent *bev, void *ptr)
 	}
 
 	if (buffer_len < hdr.len + sizeof(struct hmsg_header))
-		return;		/* Not enough data yet */
+		return; /* Not enough data yet */
 	if (hdr.len > 0 && (data = malloc(hdr.len)) == NULL) {
 		log_warnx("event", "not enough memory");
 		goto recv_error;
@@ -354,10 +353,9 @@ levent_ctl_recv(struct bufferevent *bev, void *ptr)
 	/* Currently, we should not receive notification acknowledgment. But if
 	 * we receive one, we can discard it. */
 	if (hdr.len == 0 && hdr.type == NOTIFICATION) return;
-	if (client_handle_client(client->cfg,
-		levent_ctl_send_cb, client,
-		hdr.type, data, hdr.len,
-		&client->subscribed) == -1) goto recv_error;
+	if (client_handle_client(client->cfg, levent_ctl_send_cb, client, hdr.type,
+		data, hdr.len, &client->subscribed) == -1)
+		goto recv_error;
 	free(data);
 	return;
 
@@ -403,14 +401,13 @@ levent_ctl_accept(evutil_socket_t fd, short what, void *arg)
 	levent_make_socket_nonblocking(s);
 	TAILQ_INSERT_TAIL(&lldpd_clients, client, next);
 	if ((client->bev = bufferevent_socket_new(cfg->g_base, s,
-		    BEV_OPT_CLOSE_ON_FREE)) == NULL) {
-		log_warnx("event", "unable to allocate a new buffer event for new client");
+		 BEV_OPT_CLOSE_ON_FREE)) == NULL) {
+		log_warnx("event",
+		    "unable to allocate a new buffer event for new client");
 		close(s);
 		goto accept_failed;
 	}
-	bufferevent_setcb(client->bev,
-	    levent_ctl_recv, NULL, levent_ctl_event,
-	    client);
+	bufferevent_setcb(client->bev, levent_ctl_recv, NULL, levent_ctl_event, client);
 	bufferevent_enable(client->bev, EV_READ | EV_WRITE);
 	log_debug("event", "new client accepted");
 	/* coverity[leaked_handle]
@@ -431,13 +428,13 @@ levent_priv(evutil_socket_t fd, short what, void *arg)
 	/* Check if we have some data available. We need to pass the socket in
 	 * non-blocking mode to be able to run the check without disruption. */
 	levent_make_socket_nonblocking(fd);
-	n = read(fd, &one, 1); err = errno;
+	n = read(fd, &one, 1);
+	err = errno;
 	levent_make_socket_blocking(fd);
 
 	switch (n) {
 	case -1:
-		if (err == EAGAIN || err == EWOULDBLOCK)
-			/* No data, all good */
+		if (err == EAGAIN || err == EWOULDBLOCK) /* No data, all good */
 			return;
 		log_warnx("event", "unable to poll monitor process, exit");
 		break;
@@ -449,7 +446,8 @@ levent_priv(evutil_socket_t fd, short what, void *arg)
 		 * monitor. It would be safer to request 0 byte, but some OS
 		 * (illumos) seem to take the shortcut that by asking 0 byte,
 		 * we can just return 0 byte. */
-		log_warnx("event", "received unexpected data from monitor process, exit");
+		log_warnx("event",
+		    "received unexpected data from monitor process, exit");
 		break;
 	}
 	event_base_loopbreak(base);
@@ -459,7 +457,8 @@ static void
 levent_dump(evutil_socket_t fd, short what, void *arg)
 {
 	struct event_base *base = arg;
-	(void)fd; (void)what;
+	(void)fd;
+	(void)what;
 	log_debug("event", "dumping all events");
 	event_base_dump_events(base, stderr);
 }
@@ -467,7 +466,8 @@ static void
 levent_stop(evutil_socket_t fd, short what, void *arg)
 {
 	struct event_base *base = arg;
-	(void)fd; (void)what;
+	(void)fd;
+	(void)what;
 	event_base_loopbreak(base);
 }
 
@@ -478,12 +478,11 @@ levent_update_and_send(evutil_socket_t fd, short what, void *arg)
 	struct timeval tv;
 	long interval_ms = cfg->g_config.c_tx_interval;
 
-	(void)fd; (void)what;
+	(void)fd;
+	(void)what;
 	lldpd_loop(cfg);
-	if (cfg->g_iface_event != NULL)
-		interval_ms *= 20;
-	if (interval_ms < 30000)
-		interval_ms = 30000;
+	if (cfg->g_iface_event != NULL) interval_ms *= 20;
+	if (interval_ms < 30000) interval_ms = 30000;
 	tv.tv_sec = interval_ms / 1000;
 	tv.tv_usec = (interval_ms % 1000) * 1000;
 	event_add(cfg->g_main_loop, &tv);
@@ -492,15 +491,14 @@ levent_update_and_send(evutil_socket_t fd, short what, void *arg)
 void
 levent_update_now(struct lldpd *cfg)
 {
-	if (cfg->g_main_loop)
-		event_active(cfg->g_main_loop, EV_TIMEOUT, 1);
+	if (cfg->g_main_loop) event_active(cfg->g_main_loop, EV_TIMEOUT, 1);
 }
 
 void
 levent_send_now(struct lldpd *cfg)
 {
 	struct lldpd_hardware *hardware;
-	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries) {
+	TAILQ_FOREACH (hardware, &cfg->g_hardware, h_entries) {
 		if (hardware->h_timer)
 			event_active(hardware->h_timer, EV_TIMEOUT, 1);
 		else
@@ -517,21 +515,18 @@ levent_init(struct lldpd *cfg)
 	event_set_log_callback(levent_log_cb);
 	if (!(cfg->g_base = event_base_new()))
 		fatalx("event", "unable to create a new libevent base");
-	log_info("event", "libevent %s initialized with %s method",
-		  event_get_version(),
-		  event_base_get_method(cfg->g_base));
+	log_info("event", "libevent %s initialized with %s method", event_get_version(),
+	    event_base_get_method(cfg->g_base));
 
 	/* Setup SNMP */
 #ifdef USE_SNMP
 	if (cfg->g_snmp) {
 		agent_init(cfg, cfg->g_snmp_agentx);
-		cfg->g_snmp_timeout = evtimer_new(cfg->g_base,
-		    levent_snmp_timeout,
-		    cfg);
+		cfg->g_snmp_timeout =
+		    evtimer_new(cfg->g_base, levent_snmp_timeout, cfg);
 		if (!cfg->g_snmp_timeout)
 			fatalx("event", "unable to setup timeout function for SNMP");
-		if ((cfg->g_snmp_fds =
-			malloc(sizeof(struct ev_l))) == NULL)
+		if ((cfg->g_snmp_fds = malloc(sizeof(struct ev_l))) == NULL)
 			fatalx("event", "unable to allocate memory for SNMP events");
 		TAILQ_INIT(levent_snmp_fds(cfg));
 	}
@@ -539,9 +534,8 @@ levent_init(struct lldpd *cfg)
 
 	/* Setup loop that will run every X seconds. */
 	log_debug("event", "register loop timer");
-	if (!(cfg->g_main_loop = event_new(cfg->g_base, -1, 0,
-					   levent_update_and_send,
-					   cfg)))
+	if (!(cfg->g_main_loop =
+		    event_new(cfg->g_base, -1, 0, levent_update_and_send, cfg)))
 		fatalx("event", "unable to setup main timer");
 	event_active(cfg->g_main_loop, EV_TIMEOUT, 1);
 
@@ -550,8 +544,8 @@ levent_init(struct lldpd *cfg)
 	log_debug("event", "register Unix socket");
 	TAILQ_INIT(&lldpd_clients);
 	levent_make_socket_nonblocking(cfg->g_ctl);
-	if ((ctl_event = event_new(cfg->g_base, cfg->g_ctl,
-		    EV_READ|EV_PERSIST, levent_ctl_accept, cfg)) == NULL)
+	if ((ctl_event = event_new(cfg->g_base, cfg->g_ctl, EV_READ | EV_PERSIST,
+		 levent_ctl_accept, cfg)) == NULL)
 		fatalx("event", "unable to setup control socket event");
 	event_add(ctl_event, NULL);
 
@@ -559,20 +553,16 @@ levent_init(struct lldpd *cfg)
 	struct event *monitor_event;
 	log_debug("event", "monitor the monitor process");
 	if ((monitor_event = event_new(cfg->g_base, priv_fd(PRIV_UNPRIVILEGED),
-		    EV_READ|EV_PERSIST, levent_priv, cfg->g_base)) == NULL)
+		 EV_READ | EV_PERSIST, levent_priv, cfg->g_base)) == NULL)
 		fatalx("event", "unable to monitor monitor process");
 	event_add(monitor_event, NULL);
 
 	/* Signals */
 	log_debug("event", "register signals");
-	evsignal_add(evsignal_new(cfg->g_base, SIGUSR1,
-		levent_dump, cfg->g_base),
+	evsignal_add(evsignal_new(cfg->g_base, SIGUSR1, levent_dump, cfg->g_base),
 	    NULL);
-	evsignal_add(evsignal_new(cfg->g_base, SIGINT,
-		levent_stop, cfg->g_base),
-	    NULL);
-	evsignal_add(evsignal_new(cfg->g_base, SIGTERM,
-		levent_stop, cfg->g_base),
+	evsignal_add(evsignal_new(cfg->g_base, SIGINT, levent_stop, cfg->g_base), NULL);
+	evsignal_add(evsignal_new(cfg->g_base, SIGTERM, levent_stop, cfg->g_base),
 	    NULL);
 }
 
@@ -594,12 +584,10 @@ levent_loop(struct lldpd *cfg)
 			break;
 	} while (event_base_loop(cfg->g_base, EVLOOP_ONCE) == 0);
 
-	if (cfg->g_iface_timer_event != NULL)
-		event_free(cfg->g_iface_timer_event);
+	if (cfg->g_iface_timer_event != NULL) event_free(cfg->g_iface_timer_event);
 
 #ifdef USE_SNMP
-	if (cfg->g_snmp)
-		agent_shutdown();
+	if (cfg->g_snmp) agent_shutdown();
 #endif /* USE_SNMP */
 
 	levent_ctl_close_clients();
@@ -609,10 +597,8 @@ levent_loop(struct lldpd *cfg)
 void
 levent_shutdown(struct lldpd *cfg)
 {
-	if (cfg->g_iface_event)
-		event_free(cfg->g_iface_event);
-	if (cfg->g_cleanup_timer)
-		event_free(cfg->g_cleanup_timer);
+	if (cfg->g_iface_event) event_free(cfg->g_iface_event);
+	if (cfg->g_cleanup_timer) event_free(cfg->g_cleanup_timer);
 	event_base_free(cfg->g_base);
 }
 
@@ -622,8 +608,7 @@ levent_hardware_recv(evutil_socket_t fd, short what, void *arg)
 	struct lldpd_hardware *hardware = arg;
 	struct lldpd *cfg = hardware->h_cfg;
 	(void)what;
-	log_debug("event", "received something for %s",
-	    hardware->h_ifname);
+	log_debug("event", "received something for %s", hardware->h_ifname);
 	lldpd_recv(cfg, hardware, fd);
 	levent_schedule_cleanup(cfg);
 }
@@ -632,8 +617,7 @@ void
 levent_hardware_init(struct lldpd_hardware *hardware)
 {
 	log_debug("event", "initialize events for %s", hardware->h_ifname);
-	if ((hardware->h_recv =
-		malloc(sizeof(struct ev_l))) == NULL) {
+	if ((hardware->h_recv = malloc(sizeof(struct ev_l))) == NULL) {
 		log_warnx("event", "unable to allocate memory for %s",
 		    hardware->h_ifname);
 		return;
@@ -654,18 +638,16 @@ levent_hardware_add_fd(struct lldpd_hardware *hardware, int fd)
 		return;
 	}
 	levent_make_socket_nonblocking(fd);
-	if ((hfd->ev = event_new(hardware->h_cfg->g_base, fd,
-		    EV_READ | EV_PERSIST,
-		    levent_hardware_recv,
-		    hardware)) == NULL) {
+	if ((hfd->ev = event_new(hardware->h_cfg->g_base, fd, EV_READ | EV_PERSIST,
+		 levent_hardware_recv, hardware)) == NULL) {
 		log_warnx("event", "unable to allocate a new event for %s",
-			hardware->h_ifname);
+		    hardware->h_ifname);
 		free(hfd);
 		return;
 	}
 	if (event_add(hfd->ev, NULL) == -1) {
 		log_warnx("event", "unable to schedule new event for %s",
-			hardware->h_ifname);
+		    hardware->h_ifname);
 		event_free(hfd->ev);
 		free(hfd);
 		return;
@@ -684,9 +666,7 @@ levent_hardware_release(struct lldpd_hardware *hardware)
 	if (!hardware->h_recv) return;
 
 	log_debug("event", "release events for %s", hardware->h_ifname);
-	for (ev = TAILQ_FIRST(levent_hardware_fds(hardware));
-	     ev;
-	     ev = ev_next) {
+	for (ev = TAILQ_FIRST(levent_hardware_fds(hardware)); ev; ev = ev_next) {
 		ev_next = TAILQ_NEXT(ev, next);
 		/* We may close several time the same FD. This is harmless. */
 		close(event_get_fd(ev->ev));
@@ -701,8 +681,7 @@ static void
 levent_iface_trigger(evutil_socket_t fd, short what, void *arg)
 {
 	struct lldpd *cfg = arg;
-	log_debug("event",
-	    "triggering update of all interfaces");
+	log_debug("event", "triggering update of all interfaces");
 	lldpd_update_localports(cfg);
 }
 
@@ -717,9 +696,7 @@ levent_iface_recv(evutil_socket_t fd, short what, void *arg)
 		/* Discard the message */
 		while (1) {
 			n = read(fd, buffer, sizeof(buffer));
-			if (n == -1 &&
-			    (errno == EWOULDBLOCK ||
-				errno == EAGAIN)) break;
+			if (n == -1 && (errno == EWOULDBLOCK || errno == EAGAIN)) break;
 			if (n == -1) {
 				log_warn("event",
 				    "unable to receive interface change notification message");
@@ -737,21 +714,20 @@ levent_iface_recv(evutil_socket_t fd, short what, void *arg)
 
 	/* Schedule local port update. We don't run it right away because we may
 	 * receive a batch of events like this. */
-	struct timeval one_sec = {1, 0};
+	struct timeval one_sec = { 1, 0 };
 	TRACE(LLDPD_INTERFACES_NOTIFICATION());
 	log_debug("event",
 	    "received notification change, schedule an update of all interfaces in one second");
 	if (cfg->g_iface_timer_event == NULL) {
 		if ((cfg->g_iface_timer_event = evtimer_new(cfg->g_base,
-			    levent_iface_trigger, cfg)) == NULL) {
+			 levent_iface_trigger, cfg)) == NULL) {
 			log_warnx("event",
 			    "unable to create a new event to trigger interface update");
 			return;
 		}
 	}
 	if (evtimer_add(cfg->g_iface_timer_event, &one_sec) == -1) {
-		log_warnx("event",
-		    "unable to schedule interface updates");
+		log_warnx("event", "unable to schedule interface updates");
 		return;
 	}
 }
@@ -759,19 +735,17 @@ levent_iface_recv(evutil_socket_t fd, short what, void *arg)
 int
 levent_iface_subscribe(struct lldpd *cfg, int socket)
 {
-	log_debug("event", "subscribe to interface changes from socket %d",
-	    socket);
+	log_debug("event", "subscribe to interface changes from socket %d", socket);
 	levent_make_socket_nonblocking(socket);
-	cfg->g_iface_event = event_new(cfg->g_base, socket,
-	    EV_READ | EV_PERSIST, levent_iface_recv, cfg);
+	cfg->g_iface_event = event_new(cfg->g_base, socket, EV_READ | EV_PERSIST,
+	    levent_iface_recv, cfg);
 	if (cfg->g_iface_event == NULL) {
 		log_warnx("event",
 		    "unable to allocate a new event for interface changes");
 		return -1;
 	}
 	if (event_add(cfg->g_iface_event, NULL) == -1) {
-		log_warnx("event",
-		    "unable to schedule new interface changes event");
+		log_warnx("event", "unable to schedule new interface changes event");
 		event_free(cfg->g_iface_event);
 		cfg->g_iface_event = NULL;
 		return -1;
@@ -795,8 +769,7 @@ levent_schedule_cleanup(struct lldpd *cfg)
 	}
 	cfg->g_cleanup_timer = evtimer_new(cfg->g_base, levent_trigger_cleanup, cfg);
 	if (cfg->g_cleanup_timer == NULL) {
-		log_warnx("event",
-		    "unable to allocate a new event for cleanup tasks");
+		log_warnx("event", "unable to allocate a new event for cleanup tasks");
 		return;
 	}
 
@@ -806,28 +779,24 @@ levent_schedule_cleanup(struct lldpd *cfg)
 	time_t next;
 	struct lldpd_hardware *hardware;
 	struct lldpd_port *port;
-	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries) {
-		TAILQ_FOREACH(port, &hardware->h_rports, p_entries) {
+	TAILQ_FOREACH (hardware, &cfg->g_hardware, h_entries) {
+		TAILQ_FOREACH (port, &hardware->h_rports, p_entries) {
 			if (now >= port->p_lastupdate + port->p_ttl) {
 				tv.tv_sec = 0;
-				log_debug("event", "immediate cleanup on port %s (%lld, %d, %lld)",
-				    hardware->h_ifname,
-				    (long long)now,
-				    port->p_ttl,
+				log_debug("event",
+				    "immediate cleanup on port %s (%lld, %d, %lld)",
+				    hardware->h_ifname, (long long)now, port->p_ttl,
 				    (long long)port->p_lastupdate);
 				break;
 			}
 			next = port->p_ttl - (now - port->p_lastupdate);
-			if (next < tv.tv_sec)
-				tv.tv_sec = next;
+			if (next < tv.tv_sec) tv.tv_sec = next;
 		}
 	}
 
-	log_debug("event", "next cleanup in %ld seconds",
-	    (long)tv.tv_sec);
+	log_debug("event", "next cleanup in %ld seconds", (long)tv.tv_sec);
 	if (event_add(cfg->g_cleanup_timer, &tv) == -1) {
-		log_warnx("event",
-		    "unable to schedule cleanup task");
+		log_warnx("event", "unable to schedule cleanup task");
 		event_free(cfg->g_cleanup_timer);
 		cfg->g_cleanup_timer = NULL;
 		return;
@@ -840,13 +809,11 @@ levent_send_pdu(evutil_socket_t fd, short what, void *arg)
 	struct lldpd_hardware *hardware = arg;
 	int tx_interval = hardware->h_cfg->g_config.c_tx_interval;
 
-	log_debug("event", "trigger sending PDU for port %s",
-	    hardware->h_ifname);
+	log_debug("event", "trigger sending PDU for port %s", hardware->h_ifname);
 	lldpd_send(hardware);
 
 #ifdef ENABLE_LLDPMED
-	if (hardware->h_tx_fast > 0)
-		hardware->h_tx_fast--;
+	if (hardware->h_tx_fast > 0) hardware->h_tx_fast--;
 
 	if (hardware->h_tx_fast > 0)
 		tx_interval = hardware->h_cfg->g_config.c_tx_fast_interval * 1000;
@@ -867,11 +834,10 @@ levent_send_pdu(evutil_socket_t fd, short what, void *arg)
 void
 levent_schedule_pdu(struct lldpd_hardware *hardware)
 {
-	log_debug("event", "schedule sending PDU on %s",
-	    hardware->h_ifname);
+	log_debug("event", "schedule sending PDU on %s", hardware->h_ifname);
 	if (hardware->h_timer == NULL) {
-		hardware->h_timer = evtimer_new(hardware->h_cfg->g_base,
-		    levent_send_pdu, hardware);
+		hardware->h_timer =
+		    evtimer_new(hardware->h_cfg->g_base, levent_send_pdu, hardware);
 		if (hardware->h_timer == NULL) {
 			log_warnx("event", "unable to schedule PDU sending for port %s",
 			    hardware->h_ifname);
@@ -929,17 +895,14 @@ levent_recv_error(int fd, const char *source)
 	do {
 		ssize_t n;
 		char buf[1024] = {};
-		struct msghdr msg = {
-			.msg_control = buf,
-			.msg_controllen = sizeof(buf)
-		};
+		struct msghdr msg = { .msg_control = buf,
+			.msg_controllen = sizeof(buf) };
 		if ((n = recvmsg(fd, &msg, MSG_ERRQUEUE | MSG_DONTWAIT)) <= 0) {
 			return;
 		}
 		struct cmsghdr *cmsg = CMSG_FIRSTHDR(&msg);
 		if (cmsg == NULL)
-			log_warnx("event", "received unknown error on %s",
-			    source);
+			log_warnx("event", "received unknown error on %s", source);
 		else
 			log_warnx("event", "received error (level=%d/type=%d) on %s",
 			    cmsg->cmsg_level, cmsg->cmsg_type, source);
