@@ -26,6 +26,7 @@
 #include <string.h>
 #include <errno.h>
 #include <time.h>
+#include "log.h"
 
 /* By default, logging is done on stderr. */
 static int use_syslog = 0;
@@ -152,7 +153,7 @@ static void
 vlog(int pri, const char *token, const char *fmt, va_list ap)
 {
 	if (logh) {
-		char *result;
+		char *result = NULL;
 		if (vasprintf(&result, fmt, ap) != -1) {
 			logh(pri, result);
 			free(result);
@@ -190,7 +191,7 @@ vlog(int pri, const char *token, const char *fmt, va_list ap)
 void
 log_warn(const char *token, const char *emsg, ...)
 {
-	char *nfmt;
+	char *nfmt = NULL;
 	va_list ap;
 
 	/* best effort to even work in out of memory situations */
